@@ -113,10 +113,9 @@ class Generator(object):
 
         # * build_dir
         # build_dir: relative to the ssg.yml, the dir that contains the output
-        if build_dir := self.config.get("build_dir"):
-            self.build_dir = os.path.join(self.root_dir, build_dir)
-        else:
-            self.build_dir = os.path.join(self.base_dir, "_build")
+        if not (build_dir := self.config.get("build_dir")):
+            build_dir = "_build"
+        self.build_dir = os.path.join(self.root_dir, build_dir)
 
         self.public_dir = os.path.join(self.base_dir, "public")
         self.static_dir = os.path.join(self.base_dir, "static")
@@ -149,21 +148,21 @@ class Generator(object):
         self.static_url = self.site_config.get("static_url")
         self._context_root = "./"
         # self._data = {}
-        self._load_data_resources()
+        self.load_data_resources()
 
         self.print_info = False
 
         self._init_jinja({
-            "get_page_context": self._get_page,
+            "get_page_meta": self._get_page,
             "get_url_for": self._get_page_url,
             "get_static_url_for": self._get_static_url,
             "get_static_bundle_url_for": self._get_page_static_bundle_url,
             "get_public_url_for": None,
-            "get_resources": self._get_resources,
+            "get_data": self._get_resources,
             "get_site": self._get_site,
             "format_date": lambda dt, format="MM/DD/YYYY h:mm a": arrow.get(dt).format(format),
             "get_current_date": lambda: arrow.now(),
-            "site": self.site_config,
+            "__site__": self.site_config,
             "__info__": self._load_info()
         })
  
@@ -330,7 +329,7 @@ class Generator(object):
         url = "/" + dest_file.replace("index.html", "")
         return dest_file, url
 
-    def _load_data_resources(self):
+    def load_data_resources(self):
         global resources__
         data = {}
 
@@ -393,7 +392,7 @@ class Generator(object):
             _default_page = {
                 "build_dir": self.build_dir,
                 "filepath": None,
-                "context": {"page": {}, "this": {}},
+                "context": {"page": {}, "this": {}, "__page__": {}},
                 "content": "",
                 "markup": None,
                 "template": None,
@@ -407,7 +406,7 @@ class Generator(object):
                     return [{
                         "build_dir": self.build_dir,
                         "filepath": mdata.get("filepath"),
-                        "context": {"page": mdata, "this": mdata},
+                        "context": {"page": mdata, "this": mdata, "__page__": mdata},
                         "content": mdata.get("content"),
                         "markup": mdata.get("markup"),
                         "template": mdata.get("template"),
@@ -494,7 +493,8 @@ class Generator(object):
                                 "filepath": permalink,
                                 "context": {
                                     "page": this,
-                                    "this": this
+                                    "this": this,
+                                    "__page__": this
                                 },
                                 "content": mdata.get("content"),
                                 "markup": mdata.get("markup"),
@@ -598,7 +598,8 @@ class Generator(object):
                                 "filepath": permalink,
                                 "context": {
                                     "page": this,
-                                    "this": this
+                                    "this": this,
+                                    "__page__": this
                                 },
                                 "content": mdata.get("content"),
                                 "markup": mdata.get("markup"),
@@ -745,6 +746,10 @@ class Generator(object):
         if "url" not in _context["page"]:
             _context["page"]["url"] = "/" + \
                 filepath.lstrip("/").replace("index.html", "")
+        
+        if "page" in _context:
+            _context["__page__"] = _context.get("page")
+
         self._reset_page_context_assets(_context)
 
         #! redirect
